==> rendition-18.1.0.tgz: package/dist_esm5/extra/JsonSchemaRenderer/JsonSchemaRendererPlayground/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import keys from 'lodash/keys';
import get from 'lodash/get';
import escapeRegExp from 'lodash/escapeRegExp';
import filter from 'lodash/filter';
import memoize from 'lodash/memoize';
import JsonSchema7Schema from 'ajv/lib/refs/json-schema-draft-07.json';
import jsone from 'json-e';
import styled from 'styled-components';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faUndo } from '@fortawesome/free-solid-svg-icons/faUndo';
import asRendition from '../../../asRendition';
import { Flex } from '../../../components/Flex';
import { Box } from '../../../components/Box';
import Card from '../../../components/Card';
import Select from '../../../components/Select';
import Button from '../../../components/Button';
import Heading from '../../../components/Heading';
import JsonSchemaRenderer from '../index';
import JsonEditor from './JsonEditor';
import { generateUiSchemaMetaSchema } from './util';
var EXTRA_FORMATS = [
    {
        name: 'markdown',
        format: '.*',
    },
];
var SlimCard = styled(Card)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t& > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t}\n"], ["\n\t& > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t}\n"])));
var ResultCard = styled(SlimCard)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t& > div > div:last-child {\n\t\tdisplay: flex;\n\t}\n"], ["\n\t& > div > div:last-child {\n\t\tdisplay: flex;\n\t}\n"])));
var EditCard = styled(SlimCard)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\t& > div > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t\tmin-height: 0;\n\t}\n"], ["\n\t& > div > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t\tmin-height: 0;\n\t}\n"])));
var defaultJsonProps = { value: {}, schema: {}, uiSchema: {} };
var defaultRegExp = new RegExp('');
var getExampleNames = memoize(function (examples) { return keys(examples); });
var commonCardProps = {
    small: true,
    backgroundColor: 'quartenary.light',
};
var JsonSchemaRendererPlayground = function (_a) {
    var _b = _a.title, title = _b === void 0 ? 'JSON Playground' : _b, examples = _a.examples, props = __rest(_a, ["title", "examples"]);
    var _c = React.useState(''), selectedExample = _c[0], setSelectedExample = _c[1];
    var _d = React.useState(defaultRegExp), searchTermRegExp = _d[0], setSearchTermRegExp = _d[1];
    var _e = React.useState({}), value = _e[0], setValue = _e[1];
    var _f = React.useState({}), schema = _f[0], setSchema = _f[1];
    var _g = React.useState({}), uiSchema = _g[0], setUiSchema = _g[1];
    var _h = React.useState(JSON.stringify(value, null, 2)), valueStr = _h[0], setValueStr = _h[1];
    var _j = React.useState(JSON.stringify(schema, null, 2)), schemaStr = _j[0], setSchemaStr = _j[1];
    var _k = React.useState(JSON.stringify(uiSchema, null, 2)), uiSchemaStr = _k[0], setUiSchemaStr = _k[1];
    var _l = React.useState(true), isValueJsonValid = _l[0], setIsValueJsonValid = _l[1];
    var _m = React.useState(true), isSchemaJsonValid = _m[0], setIsSchemaJsonValid = _m[1];
    var _o = React.useState(true), isUiSchemaJsonValid = _o[0], setIsUiSchemaJsonValid = _o[1];
    var _p = React.useState({}), uiSchemaMetaSchema = _p[0], setUiSchemaMetaSchema = _p[1];
    var _q = React.useState(defaultJsonProps), jsonProps = _q[0], setJsonProps = _q[1];
    var reset = React.useCallback(function () {
        setSelectedExample('');
        setSearchTermRegExp(defaultRegExp);
    }, [setSelectedExample, setSearchTermRegExp]);
    React.useEffect(function () {
        try {
            setValue(JSON.parse(valueStr));
            setIsValueJsonValid(true);
        }
        catch (_a) {
            setIsValueJsonValid(false);
        }
    }, [valueStr]);
    React.useEffect(function () {
        try {
            setSchema(JSON.parse(schemaStr));
            setIsSchemaJsonValid(true);
        }
        catch (_a) {
            setIsSchemaJsonValid(false);
        }
    }, [schemaStr]);
    React.useEffect(function () {
        try {
            setUiSchema(JSON.parse(uiSchemaStr));
            setIsUiSchemaJsonValid(true);
        }
        catch (_a) {
            setIsUiSchemaJsonValid(false);
        }
    }, [uiSchemaStr]);
    React.useEffect(function () {
        var example = get(examples, selectedExample, defaultJsonProps);
        setValueStr(JSON.stringify(example.value, null, 2));
        setSchemaStr(JSON.stringify(example.schema, null, 2));
        setUiSchemaStr(JSON.stringify(example.uiSchema, null, 2));
        setSearchTermRegExp(defaultRegExp);
    }, [selectedExample]);
    React.useEffect(function () {
        try {
            var processedUiSchema = jsone(uiSchema, { source: value });
            var newMetaSchema = generateUiSchemaMetaSchema({
                value: value,
                schema: schema,
                uiSchema: processedUiSchema,
            });
            setUiSchemaMetaSchema(newMetaSchema);
            setJsonProps({ value: value, schema: schema, uiSchema: uiSchema });
        }
        catch (error) {
            console.error('Failed to parse schemas', error);
        }
    }, [uiSchema, schema, value]);
    var unfilteredExampleNames = getExampleNames(examples);
    var exampleNames = searchTermRegExp.source
        ? filter(unfilteredExampleNames, function (name) { return searchTermRegExp.test(name); })
        : unfilteredExampleNames;
    return (React.createElement(Flex, __assign({ p: 3 }, props),
        React.createElement(Flex, { flex: "1 1 50%", minWidth: 0, flexDirection: "column", pr: 2 },
            React.createElement(Flex, { mb: 3, alignItems: "center", justifyContent: "space-between" },
                React.createElement(Heading.h3, null, title),
                React.createElement(Flex, { ml: 3, alignItems: "center", justifyContent: "flex-end", flex: 1 },
                    React.createElement(Box, { flex: 1 },
                        React.createElement(Select, { placeholder: "Load an example...", emptySearchMessage: "No results", searchPlaceholder: "Search...", onSearch: function (s) {
                                return setSearchTermRegExp(new RegExp(escapeRegExp(s), 'i'));
                            }, value: selectedExample, options: exampleNames, onChange: function (_a) {
                                var option = _a.option;
                                setSelectedExample(option);
                            } })),
                    React.createElement(Button, { ml: 2, tooltip: { text: 'Reset', placement: 'right' }, icon: React.createElement(FontAwesomeIcon, { icon: faUndo }), onClick: reset }))),
            React.createElement(EditCard, __assign({ flex: 1 }, commonCardProps),
                React.createElement(JsonEditor, { title: "Data", value: valueStr, onChange: setValueStr, schema: schema, isValid: isValueJsonValid }),
                React.createElement(JsonEditor, { title: "Schema", value: schemaStr, onChange: setSchemaStr, schema: JsonSchema7Schema, isValid: isSchemaJsonValid }),
                React.createElement(JsonEditor, { title: "UI Schema", value: uiSchemaStr, onChange: setUiSchemaStr, schema: uiSchemaMetaSchema, isValid: isUiSchemaJsonValid }))),
        React.createElement(Flex, { flex: "1 1 50%", minWidth: 0, flexDirection: "column", pl: 2 },
            React.createElement(ResultCard, __assign({ flex: 1 }, commonCardProps, { title: "Result" }),
                React.createElement(JsonSchemaRenderer, __assign({}, jsonProps, { p: 2, pb: 1, validate: true, backgroundColor: "#fff", extraFormats: EXTRA_FORMATS }))))));
};
export default asRendition(JsonSchemaRendererPlayground);
var templateObject_1, templateObject_2, templateObject_3;

==> rendition-18.4.1.tgz: package/dist_esm5/extra/JsonSchemaRenderer/JsonSchemaRendererPlayground/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import keys from 'lodash/keys';
import get from 'lodash/get';
import escapeRegExp from 'lodash/escapeRegExp';
import filter from 'lodash/filter';
import memoize from 'lodash/memoize';
import JsonSchema7Schema from 'ajv/lib/refs/json-schema-draft-07.json';
import styled from 'styled-components';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faUndo } from '@fortawesome/free-solid-svg-icons/faUndo';
import asRendition from '../../../asRendition';
import { Flex } from '../../../components/Flex';
import { Box } from '../../../components/Box';
import Card from '../../../components/Card';
import Select from '../../../components/Select';
import Button from '../../../components/Button';
import Heading from '../../../components/Heading';
import Checkbox from '../../../components/Checkbox';
import JsonSchemaRenderer from '../index';
import { CONTEXT_FUNCTIONS } from '../examples';
import JsonEditor from './JsonEditor';
import { generateUiSchemaMetaSchema } from './util';
var EXTRA_FORMATS = [
    {
        name: 'markdown',
        format: '.*',
    },
];
var SlimCard = styled(Card)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t& > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t}\n"], ["\n\t& > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t}\n"])));
var ResultCard = styled(SlimCard)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t& > div > div:last-child {\n\t\tdisplay: flex;\n\t}\n"], ["\n\t& > div > div:last-child {\n\t\tdisplay: flex;\n\t}\n"])));
var EditCard = styled(SlimCard)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\t& > div > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t\tmin-height: 0;\n\t}\n"], ["\n\t& > div > div {\n\t\tflex: 1;\n\t\tdisplay: flex;\n\t\tflex-direction: column;\n\t\tmin-height: 0;\n\t}\n"])));
var defaultJsonProps = { value: {}, schema: {}, uiSchema: {} };
var defaultRegExp = new RegExp('');
var getExampleNames = memoize(function (examples) { return keys(examples); });
var commonCardProps = {
    small: true,
    backgroundColor: 'quartenary.light',
};
var JsonSchemaRendererPlayground = function (_a) {
    var _b = _a.title, title = _b === void 0 ? 'JSON Playground' : _b, examples = _a.examples, props = __rest(_a, ["title", "examples"]);
    var _c = React.useState(true), validate = _c[0], setValidate = _c[1];
    var _d = React.useState(''), selectedExample = _d[0], setSelectedExample = _d[1];
    var _e = React.useState(defaultRegExp), searchTermRegExp = _e[0], setSearchTermRegExp = _e[1];
    var _f = React.useState({}), value = _f[0], setValue = _f[1];
    var _g = React.useState({}), schema = _g[0], setSchema = _g[1];
    var _h = React.useState({}), uiSchema = _h[0], setUiSchema = _h[1];
    var _j = React.useState(JSON.stringify(value, null, 2)), valueStr = _j[0], setValueStr = _j[1];
    var _k = React.useState(JSON.stringify(schema, null, 2)), schemaStr = _k[0], setSchemaStr = _k[1];
    var _l = React.useState(JSON.stringify(uiSchema, null, 2)), uiSchemaStr = _l[0], setUiSchemaStr = _l[1];
    var _m = React.useState(true), isValueJsonValid = _m[0], setIsValueJsonValid = _m[1];
    var _o = React.useState(true), isSchemaJsonValid = _o[0], setIsSchemaJsonValid = _o[1];
    var _p = React.useState(true), isUiSchemaJsonValid = _p[0], setIsUiSchemaJsonValid = _p[1];
    var _q = React.useState({}), uiSchemaMetaSchema = _q[0], setUiSchemaMetaSchema = _q[1];
    var _r = React.useState(defaultJsonProps), jsonProps = _r[0], setJsonProps = _r[1];
    var reset = React.useCallback(function () {
        setSelectedExample('');
        setSearchTermRegExp(defaultRegExp);
    }, [setSelectedExample, setSearchTermRegExp]);
    React.useEffect(function () {
        try {
            setValue(JSON.parse(valueStr));
            setIsValueJsonValid(true);
        }
        catch (_a) {
            setIsValueJsonValid(false);
        }
    }, [valueStr]);
    React.useEffect(function () {
        try {
            setSchema(JSON.parse(schemaStr));
            setIsSchemaJsonValid(true);
        }
        catch (_a) {
            setIsSchemaJsonValid(false);
        }
    }, [schemaStr]);
    React.useEffect(function () {
        try {
            setUiSchema(JSON.parse(uiSchemaStr));
            setIsUiSchemaJsonValid(true);
        }
        catch (_a) {
            setIsUiSchemaJsonValid(false);
        }
    }, [uiSchemaStr]);
    React.useEffect(function () {
        var example = get(examples, selectedExample, defaultJsonProps);
        setValueStr(JSON.stringify(example.value, null, 2));
        setSchemaStr(JSON.stringify(example.schema, null, 2));
        setUiSchemaStr(JSON.stringify(example.uiSchema, null, 2));
        setSearchTermRegExp(defaultRegExp);
    }, [selectedExample]);
    React.useEffect(function () {
        try {
            var newMetaSchema = generateUiSchemaMetaSchema({
                value: value,
                schema: schema,
                uiSchema: uiSchema,
                extraContext: __assign(__assign({}, CONTEXT_FUNCTIONS), { root: value }),
            });
            setUiSchemaMetaSchema(newMetaSchema);
            setJsonProps({ value: value, schema: schema, uiSchema: uiSchema });
        }
        catch (error) {
            console.error('Failed to parse schemas', error);
        }
    }, [uiSchema, schema, value]);
    var unfilteredExampleNames = getExampleNames(examples);
    var exampleNames = searchTermRegExp.source
        ? filter(unfilteredExampleNames, function (name) { return searchTermRegExp.test(name); })
        : unfilteredExampleNames;
    return (React.createElement(Flex, __assign({ p: 3 }, props),
        React.createElement(Flex, { flex: "1 1 50%", minWidth: 0, flexDirection: "column", pr: 2 },
            React.createElement(Flex, { mb: 3, alignItems: "center", justifyContent: "space-between" },
                React.createElement(Heading.h3, null, title),
                React.createElement(Flex, { ml: 3, alignItems: "center", justifyContent: "flex-end", flex: 1 },
                    React.createElement(Box, { flex: 1 },
                        React.createElement(Select, { placeholder: "Load an example...", emptySearchMessage: "No results", searchPlaceholder: "Search...", onSearch: function (s) {
                                return setSearchTermRegExp(new RegExp(escapeRegExp(s), 'i'));
                            }, value: selectedExample, options: exampleNames, onChange: function (_a) {
                                var option = _a.option;
                                setSelectedExample(option);
                            } })),
                    React.createElement(Button, { ml: 2, tooltip: { text: 'Reset', placement: 'right' }, icon: React.createElement(FontAwesomeIcon, { icon: faUndo }), onClick: reset }))),
            React.createElement(EditCard, __assign({ flex: 1 }, commonCardProps),
                React.createElement(JsonEditor, { title: "Data", value: valueStr, onChange: setValueStr, schema: schema, isValid: isValueJsonValid }),
                React.createElement(JsonEditor, { title: "Schema", value: schemaStr, onChange: setSchemaStr, schema: JsonSchema7Schema, isValid: isSchemaJsonValid }),
                React.createElement(JsonEditor, { title: "UI Schema", value: uiSchemaStr, onChange: setUiSchemaStr, schema: uiSchemaMetaSchema, isValid: isUiSchemaJsonValid }))),
        React.createElement(Flex, { flex: "1 1 50%", minWidth: 0, flexDirection: "column", pl: 2 },
            React.createElement(ResultCard, __assign({ flex: 1 }, commonCardProps, { title: "Result", cta: React.createElement(Checkbox, { checked: validate, label: "Validate", onChange: function (e) { return setValidate(e.target.checked); } }) }),
                React.createElement(JsonSchemaRenderer, __assign({}, jsonProps, { p: 2, pb: 1, validate: validate, backgroundColor: "#fff", extraFormats: EXTRA_FORMATS, extraContext: __assign(__assign({}, CONTEXT_FUNCTIONS), { root: jsonProps.value }) }))))));
};
export default asRendition(JsonSchemaRendererPlayground);
var templateObject_1, templateObject_2, templateObject_3;
